==> mingw-w64-freecad-1.0rc2-1.src.tar.zst: FreeCAD-1.0rc2/src/Mod/Help/Resources/translations/Help_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
  <context>
    <name>Form</name>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="14"/>
      <source>Help</source>
      <translation>Aide</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="20"/>
      <source>Source</source>
      <translation>Source</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="46"/>
      <location filename="../../dlgPreferencesHelp.ui" line="86"/>
      <source>Set this to a custom URL or the folder where the help files are located.
You can easily download the documentation for offline use by using the Addon
Manager and installing the &quot;offline-documentation&quot; addon. If this
field is left blank, FreeCAD will automatically search for the help files at
the default location ($USERAPPDATADIR/Mod/offline-documentation).</source>
      <translation>Définissez une URL personnalisée ou le dossier dans lequel se trouvent les fichiers d'aide. Vous pouvez facilement télécharger la documentation pour une utilisation hors ligne en utilisant le gestionnaire des extensions et en installant l'extension "offline-documentation". Si ce champ est laissé vide, FreeCAD recherchera automatiquement les fichiers d'aide à l'emplacement par défaut ($USERAPPDATADIR/Mod/offline-documentation).</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="53"/>
      <source>Custom location</source>
      <translation>Emplacement personnalisé</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="112"/>
      <source>    Translation suffix:</source>
      <translation>     Suffixe de traduction :</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="123"/>
      <source>FreeCAD Wiki (online)</source>
      <translation>Wiki de FreeCAD (en ligne)</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="29"/>
      <source>This will fetch the documentation from pages rendered on GitHub.
This is currently not available...</source>
      <translation>Ceci permet de récupérer la documentation des pages présentes sur GitHub. Non disponible pour le moment...</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="33"/>
      <source>GitHub (online)</source>
      <translation>GitHub (en ligne)</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="72"/>
      <source>A translation suffix to use, for example &quot;fr&quot;
to get French translation of the documentation.</source>
      <translation>Un suffixe de traduction à utiliser, par exemple "fr", pour obtenir une traduction française de la documentation.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="119"/>
      <source>The documentation pages will be fetched from the official
FreeCADwiki at https://wiki.freecad.org</source>
      <translation>Les pages de la documentation seront extraites du wiki officiel de FreeCAD dont l'adresse est https://wiki.freecad.org.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="139"/>
      <source>The documentation pages will be fetched from an automatic Markdown conversion
of the FreeCAD wiki,hosted on FreeCAD&apos;s GitHub account. This can be styled with a
custom stylesheet below and can look nicer than the wiki option. The &apos;Markdown&apos; or
&apos;Pandoc&apos; Python module should be installed for optimal results.</source>
      <translation>Les pages de la documentation seront extraites à partir d'une conversion automatique sous Markdown du wiki de FreeCAD, hébergé sur le compte GitHub de FreeCAD. Ceci peut être personnalisé avec une feuille de style et peut être plus agréable que l'option du wiki. Le module Python "Markdown" ou "Pandoc" doivent être installés pour des résultats optimaux.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="145"/>
      <source>Markdown version (online)</source>
      <translation>Version de Markdown (en ligne)</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="164"/>
      <source>Display</source>
      <translation>Affichage</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="170"/>
      <source>Note: if PySide Web components are not found on your system, help pages will open in your default web browser regardless of the options below</source>
      <translation>Remarque : si les composants PySide web ne sont pas présents sur votre système, les pages d'aide s'ouvriront dans votre navigateur web par défaut, quelles que soient les options ci-dessous.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="202"/>
      <source>In a FreeCAD tab</source>
      <translation>Dans un onglet de FreeCAD</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="180"/>
      <source>The documentation will open in your default web browser.</source>
      <translation>La documentation s'ouvrira dans votre navigateur par défaut.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="221"/>
      <source>The documentation will open in a dockable dialog inside the FreeCAD window,
which allows you to keep it open while working in the 3D view. This requires the PySide QtWebengineWidgets component</source>
      <translation>La documentation s'ouvrira dans une boîte de dialogue ancrée dans la fenêtre FreeCAD, ce qui vous permettra de la garder ouverte tout en travaillant dans la vue 3D. Cela nécessite le composant QtWebengineWidgets de PySide.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="256"/>
      <source>You can here indicate the path to an alternative CSS file to be used
to style the Markdown pages. This will only work if you have selected the
Markdown version above.</source>
      <translation>Vous pouvez indiquer ici le chemin d'accès à un fichier CSS alternatif à utiliser pour personnaliser les pages Markdown. Cela ne fonctionnera que si vous avez sélectionné la version Markdown ci-dessus.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="183"/>
      <source>In your default web browser</source>
      <translation>Dans votre navigateur web par défaut</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="199"/>
      <source>The documentation will open in a new tab inside the FreeCAD interface. This requires the PySide QtWebengineWidgets component</source>
      <translation>La documentation s'ouvrira dans un nouvel onglet dans l'interface de FreeCAD. Cela nécessite le composant QtWebengineWidgets de PySide.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="225"/>
      <source>In a separate, embeddable dialog</source>
      <translation>Dans une boîte de dialogue séparée, intégrable</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="241"/>
      <source>Options</source>
      <translation>Options</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="249"/>
      <source>      Custom stylesheet:</source>
      <translation>      Feuille de style personnalisée :</translation>
    </message>
  </context>
  <context>
    <name>Help</name>
    <message>
      <location filename="../../Help.py" line="75"/>
      <source>Contents for this page could not be retrieved. Please check settings under menu Edit -&gt; Preferences -&gt; General -&gt; Help</source>
      <translation>Le contenu de cette page n'a pas pu être récupéré. Vérifier les paramètres dans le menu Édition/Préférences/Générales/Aides</translation>
    </message>
    <message>
      <location filename="../../Help.py" line="79"/>
      <source>Help files location could not be determined. Please check settings under menu Edit -&gt; Preferences -&gt; General -&gt; Help</source>
      <translation>L'emplacement des fichiers d'aide n'a pas pu être déterminé. Vérifier les paramètres dans le menu Édition/Préférences/Générales/Aides</translation>
    </message>
    <message>
      <location filename="../../Help.py" line="83"/>
      <source>PySide QtWebEngineWidgets module is not available. Help rendering is done with the system browser</source>
      <translation>Le module QtWebEngineWidgets de PySide n'est pas disponible. Le rendu de l'aide est effectué avec le navigateur du système.</translation>
    </message>
    <message>
      <location filename="../../Help.py" line="87"/>
      <source>There is no Markdown renderer installed on your system, so this help page is rendered as is. Please install the Markdown or Pandoc Python modules to improve the rendering of this page.</source>
      <translation>Le moteur de rendu Markdown n'est pas installé sur votre système, cette page d'aide est donc rendue telle quelle. Installer les modules Python "Markdown" ou "Pandoc" pour améliorer le rendu de cette page.</translation>
    </message>
    <message>
      <location filename="../../Help.py" line="119"/>
      <source>Help</source>
      <translation>Aide</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Help.py" line="425"/>
      <source>General</source>
      <translation>Général</translation>
    </message>
  </context>
</TS>

==> mingw-w64-freecad-1.0.0-4.src.tar.zst: FreeCAD-1.0.0/src/Mod/Help/Resources/translations/Help_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
  <context>
    <name>Form</name>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="14"/>
      <source>Help</source>
      <translation>Aide</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="20"/>
      <source>Source</source>
      <translation>Source</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="46"/>
      <location filename="../../dlgPreferencesHelp.ui" line="86"/>
      <source>Set this to a custom URL or the folder where the help files are located.
You can easily download the documentation for offline use by using the Addon
Manager and installing the &quot;offline-documentation&quot; addon. If this
field is left blank, FreeCAD will automatically search for the help files at
the default location ($USERAPPDATADIR/Mod/offline-documentation).</source>
      <translation>Définissez une URL personnalisée ou le dossier dans lequel se trouvent les fichiers d'aide. Vous pouvez facilement télécharger la documentation pour une utilisation hors ligne en utilisant le gestionnaire des extensions et en installant l'extension "offline-documentation". Si ce champ est laissé vide, FreeCAD recherchera automatiquement les fichiers d'aide à l'emplacement par défaut ($USERAPPDATADIR/Mod/offline-documentation).</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="53"/>
      <source>Custom location</source>
      <translation>Emplacement personnalisé</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="112"/>
      <source>    Translation suffix:</source>
      <translation>     Suffixe de traduction :</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="123"/>
      <source>FreeCAD Wiki (online)</source>
      <translation>Wiki de FreeCAD (en ligne)</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="29"/>
      <source>This will fetch the documentation from pages rendered on GitHub.
This is currently not available...</source>
      <translation>Ceci permet de récupérer la documentation des pages présentes sur GitHub. Non disponible pour le moment...</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="33"/>
      <source>GitHub (online)</source>
      <translation>GitHub (en ligne)</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="72"/>
      <source>A translation suffix to use, for example &quot;fr&quot;
to get French translation of the documentation.</source>
      <translation>Un suffixe de traduction à utiliser, par exemple "fr", pour obtenir une traduction française de la documentation.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="119"/>
      <source>The documentation pages will be fetched from the official
FreeCADwiki at https://wiki.freecad.org</source>
      <translation>Les pages de la documentation seront extraites du wiki officiel de FreeCAD dont l'adresse est https://wiki.freecad.org.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="139"/>
      <source>The documentation pages will be fetched from an automatic Markdown conversion
of the FreeCAD wiki,hosted on FreeCAD&apos;s GitHub account. This can be styled with a
custom stylesheet below and can look nicer than the wiki option. The &apos;Markdown&apos; or
&apos;Pandoc&apos; Python module should be installed for optimal results.</source>
      <translation>Les pages de la documentation seront extraites à partir d'une conversion automatique sous Markdown du wiki de FreeCAD, hébergé sur le compte GitHub de FreeCAD. Ceci peut être personnalisé avec une feuille de style et peut être plus agréable que l'option du wiki. Le module Python "Markdown" ou "Pandoc" doivent être installés pour des résultats optimaux.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="145"/>
      <source>Markdown version (online)</source>
      <translation>Version de Markdown (en ligne)</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="164"/>
      <source>Display</source>
      <translation>Affichage</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="170"/>
      <source>Note: if PySide Web components are not found on your system, help pages will open in your default web browser regardless of the options below</source>
      <translation>Remarque : si les composants PySide web ne sont pas présents sur votre système, les pages d'aide s'ouvriront dans votre navigateur web par défaut, quelles que soient les options ci-dessous.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="202"/>
      <source>In a FreeCAD tab</source>
      <translation>Dans un onglet de FreeCAD</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="180"/>
      <source>The documentation will open in your default web browser.</source>
      <translation>La documentation s'ouvrira dans votre navigateur par défaut.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="221"/>
      <source>The documentation will open in a dockable dialog inside the FreeCAD window,
which allows you to keep it open while working in the 3D view. This requires the PySide QtWebengineWidgets component</source>
      <translation>La documentation s'ouvrira dans une fenêtre de dialogue ancrée dans la fenêtre FreeCAD, ce qui vous permettra de la garder ouverte tout en travaillant dans la vue 3D. Cela nécessite le composant QtWebengineWidgets de PySide.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="256"/>
      <source>You can here indicate the path to an alternative CSS file to be used
to style the Markdown pages. This will only work if you have selected the
Markdown version above.</source>
      <translation>Vous pouvez indiquer ici le chemin d'accès à un fichier CSS alternatif à utiliser pour personnaliser les pages Markdown. Cela ne fonctionnera que si vous avez sélectionné la version Markdown ci-dessus.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="183"/>
      <source>In your default web browser</source>
      <translation>Dans votre navigateur web par défaut</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="199"/>
      <source>The documentation will open in a new tab inside the FreeCAD interface. This requires the PySide QtWebengineWidgets component</source>
      <translation>La documentation s'ouvrira dans un nouvel onglet dans l'interface de FreeCAD. Cela nécessite le composant QtWebengineWidgets de PySide.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="225"/>
      <source>In a separate, embeddable dialog</source>
      <translation>Dans une fenêtre de dialogue séparée, intégrable</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="241"/>
      <source>Options</source>
      <translation>Options</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="249"/>
      <source>      Custom stylesheet:</source>
      <translation>      Feuille de style personnalisée :</translation>
    </message>
  </context>
  <context>
    <name>Help</name>
    <message>
      <location filename="../../Help.py" line="75"/>
      <source>Contents for this page could not be retrieved. Please check settings under menu Edit -&gt; Preferences -&gt; General -&gt; Help</source>
      <translation>Le contenu de cette page n'a pas pu être récupéré. Vérifier les paramètres dans le menu Édition/Préférences/Générales/Aides</translation>
    </message>
    <message>
      <location filename="../../Help.py" line="79"/>
      <source>Help files location could not be determined. Please check settings under menu Edit -&gt; Preferences -&gt; General -&gt; Help</source>
      <translation>L'emplacement des fichiers d'aide n'a pas pu être déterminé. Vérifier les paramètres dans le menu Édition/Préférences/Générales/Aides</translation>
    </message>
    <message>
      <location filename="../../Help.py" line="83"/>
      <source>PySide QtWebEngineWidgets module is not available. Help rendering is done with the system browser</source>
      <translation>Le module QtWebEngineWidgets de PySide n'est pas disponible. Le rendu de l'aide est effectué avec le navigateur du système.</translation>
    </message>
    <message>
      <location filename="../../Help.py" line="87"/>
      <source>There is no Markdown renderer installed on your system, so this help page is rendered as is. Please install the Markdown or Pandoc Python modules to improve the rendering of this page.</source>
      <translation>Le moteur de rendu Markdown n'est pas installé sur votre système, cette page d'aide est donc rendue telle quelle. Installer les modules Python "Markdown" ou "Pandoc" pour améliorer le rendu de cette page.</translation>
    </message>
    <message>
      <location filename="../../Help.py" line="119"/>
      <source>Help</source>
      <translation>Aide</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Help.py" line="432"/>
      <source>General</source>
      <translation>Général</translation>
    </message>
  </context>
</TS>
